Type: Package
Package: tidytuesdayR
Title: Access the Weekly 'TidyTuesday' Project Dataset
Version: 1.3.2
Authors@R: c(
    person("Jon", "Harmon", , "jonthegeek@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-4781-4346")),
    person("Ellis", "Hughes", , "ellishughes@live.com", role = "aut"),
    person("Thomas", "Mock", , "j.thomasmock@gmail.com", role = "ctb"),
    person("Data Science Learning Community", , , "tidytuesday@dslc.io", role = "dtc")
  )
Description: 'TidyTuesday' is a project by the 'Data Science Learning
    Community' in which they post a weekly dataset in a public data
    repository (<https://github.com/rfordatascience/tidytuesday>) for
    people to analyze and visualize. This package provides the tools to
    easily download this data and the description of the source.
License: MIT + file LICENSE
URL: https://dslc-io.github.io/tidytuesdayR/,
        https://github.com/dslc-io/tidytuesdayR
BugReports: https://github.com/dslc-io/tidytuesdayR/issues
Depends: R (>= 4.1.0)
Imports: cli, gh, glue, jsonlite, lubridate (>= 1.7.0), magrittr, purrr
        (>= 1.0.0), readr (>= 1.0.0), rlang, rvest (>= 0.3.2), stbl (>=
        0.3.0), tidyr, tools (>= 3.1.0), utils, xml2 (>= 1.2.0)
Suggests: astgrepr, base64enc, covr, dplyr, fs, knitr, magick, openssl,
        readxl (>= 1.0.0), rmarkdown, rstudioapi (>= 0.2), stringr,
        testthat (>= 3.0.0), tibble, usethis, vctrs, withr, yaml
VignetteBuilder: knitr
Config/Needs/website: pkgdown
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-12 20:37:23 UTC; jonth
Author: Jon Harmon [aut, cre] (ORCID: <https://orcid.org/0000-0003-4781-4346>),
  Ellis Hughes [aut],
  Thomas Mock [ctb],
  Data Science Learning Community [dtc]
Maintainer: Jon Harmon <jonthegeek@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-12 20:50:02 UTC
Built: R 4.5.2; ; 2026-04-12 23:10:59 UTC; unix
