# Generated by roxygen2: do not edit by hand

S3method(print,tt)
S3method(print,tt_data)
S3method(print,tt_dataset_table)
S3method(print,tt_dataset_table_list)
export("%>%")
export(last_tuesday)
export(readme)
export(tt_available)
export(tt_clean)
export(tt_curate_data)
export(tt_datasets)
export(tt_download)
export(tt_download_file)
export(tt_intro)
export(tt_load)
export(tt_load_gh)
export(tt_meta)
export(tt_save_dataset)
export(tt_submit)
export(use_tidytemplate)
importFrom(glue,glue)
importFrom(lubridate,today)
importFrom(magrittr,"%>%")
importFrom(stats,aggregate)
importFrom(stats,na.pass)
importFrom(stats,setNames)
