test_that("tt_save_dataset creates the expected files", {
  skip_on_ci()
  skip_on_cran()
  proj_dir <- withr::local_tempdir()
  full_submission_path <- fs::path(proj_dir, "tt_submission")
  usethis::local_project(proj_dir, force = TRUE, quiet = TRUE)
  expect_true(tt_save_dataset(mtcars, open = FALSE))
  file_path <- fs::path(full_submission_path, "mtcars.csv")
  expect_snapshot_file(file_path)
  file_path <- fs::path(full_submission_path, "mtcars.md")
  expect_snapshot_file(file_path)
})
