<!-- 
Describe the dataset. See previous weeks for the general format of the
description. The description is the part of the readme.md file above "The Data";
everything else will be filled in from the other md files in this directory +
automatic scripts. We usually include brief introduction along the lines of
"This week we're exploring DATASET" or "The dataset this week comes from 
SOURCE".
-->

<!-- Add a quote from the source, starting lines with a ">" character, like 
this:
> Plant traits are critical to plant form and function — including growth, 
> survival and reproduction — and therefore shape fundamental aspects of
> population and ecosystem dynamics as well as ecosystem services. Here, we 
> present a global species-level compilation of key functional traits for palms 
> (Arecaceae), a plant family with keystone importance in tropical and 
> subtropical ecosystems.
-->

> PasteQuoteHere

<!--
Optional: Add questions that users should try to answer. For example:
- How does the sizes of the different species of palms vary across sub families?
- Which fruit colors occur most often?
-->
