This week we're exploring data about the 50 states of the United States of America!
The data this week comes from the U.S. Department of Commerce, Bureau of the Census (1977) *Statistical Abstract of the United States* and *County and City Data Book* via the core R {datasets} package.

> Data sets related to the 50 states of the United States of America. Note that all data are arranged according to alphabetical order of the state names.

- Is there a relationship between income and illiteracy?
- Which states had the highest population density in 1975? Which states had the lowest?
