|variable   |class     |description                           |
|:----------|:---------|:-------------------------------------|
|state      |character |Name of the state. |
|population |character |Population estimate as of July 1, 1975. |
|income     |integer   |Per capita income in 1974. |
|illiteracy |integer   |Illiteracy in 1970, as percent of population. |
|life_exp   |double    |Life expectancy in years (1969–71). |
|murder     |double    |Murder and non-negligent manslaughter rate per 100,000 population in 1976. |
|hs_grad    |double    |Percent high-school graduates in 1970. |
|frost      |integer   |Mean number of days with minimum temperature below freezing (1931–1960) in capital or large city. |
|area       |integer   |Land area in square miles. |
