|variable |class  |description                           |
|:--------|:------|:-------------------------------------|
|mpg      |double |Describe this field in sentence case. |
|cyl      |double |Describe this field in sentence case. |
|disp     |double |Describe this field in sentence case. |
|hp       |double |Describe this field in sentence case. |
|drat     |double |Describe this field in sentence case. |
|wt       |double |Describe this field in sentence case. |
|qsec     |double |Describe this field in sentence case. |
|vs       |double |Describe this field in sentence case. |
|am       |double |Describe this field in sentence case. |
|gear     |double |Describe this field in sentence case. |
|carb     |double |Describe this field in sentence case. |
