% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tt_curate_utils.R
\name{prep_tt_curate}
\alias{prep_tt_curate}
\title{Set up a directory for dataset curation}
\usage{
prep_tt_curate(
  path = "tt_submission",
  ignore = FALSE,
  env = rlang::caller_env()
)
}
\arguments{
\item{path}{The relative path to the directory to hold your submission files
(\code{tt_submission} by default). If this directory does not exist, it will be
created.}

\item{ignore}{Should the newly created file be added to \code{.Rbuildignore}?}
}
\value{
The resolved path (invisibly).
}
\description{
Set up a directory for dataset curation
}
\keyword{internal}
