% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tt_intro.R
\name{tt_intro}
\alias{tt_intro}
\title{Create and open intro.md}
\usage{
tt_intro(
  path = "tt_submission",
  open = rlang::is_interactive(),
  ignore = FALSE
)
}
\arguments{
\item{path}{The relative path to the directory to hold your submission files
(\code{tt_submission} by default). If this directory does not exist, it will be
created.}

\item{open}{Open the newly created file for editing? Happens in RStudio, if
applicable, or via \code{\link[utils:file.edit]{utils::file.edit()}} otherwise.}

\item{ignore}{Should the newly created file be added to \code{.Rbuildignore}?}
}
\value{
A logical vector indicating whether the file was created or
modified, invisibly.
}
\description{
When curating a TidyTuesday dataset, you need to introduce the dataset. This
function creates a simple \code{intro.md} file in the specified path (creating
that path if it does not already exist), and (if possible) opens it for
editing.
}
\examples{
\dontshow{if (interactive()) withAutoprint(\{ # examplesIf}

  tt_intro()
\dontshow{\}) # examplesIf}
}
